// --8<--8<--8<--8<--
//
// Copyright (C) 2006 Smithsonian Astrophysical Observatory
//
// This file is part of scatter
//
// scatter is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// scatter is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the 
//       Free Software Foundation, Inc. 
//       51 Franklin Street, Fifth Floor
//       Boston, MA  02110-1301, USA
//
// -->8-->8-->8-->8--

#include "Photon.h"

Photon::Photon( BPipe* bpipe, void* core ) throw ( BinaryPipeException ) : MyPhoton(bpipe,core) {

  try {

    srfno        = (unsigned int *)hdrf_data( bpipe, BP_AXAF_srfno, 0 );

    surface_norm = (DVector3 *)dpktf_data( bpipe, core, BP_AXAF_surf_norm );
    energy       = (double *)dpktf_data( bpipe, core, BP_AXAF_phot_energy );
    id           = (unsigned int *)dpktf_data( bpipe, core, BP_AXAF_phot_id );
    surf_missed  = (unsigned int *)dpktf_data( bpipe, core, BP_AXAF_surf_missed );
   
  } catch( BinaryPipeException& pfe ) {

    throw;

  }

}

/**
   simple routine to get the data pointer for a named data packet field 
*/
char* Photon::dpktf_data( BPipe* bpipe, void* core, const char *name ) const 
  throw ( BinaryPipeException ) {

  DpktField *field = bpipe_dpktf( bpipe, (char*) name );
  if ( NULL == field ) {
    char msg[ 128 ];
    const char* format =
      "Photon::dpktf_data( Bpipe*, %s ) : missing `%s' field\n";
    sprintf( msg, format, name, name );
    throw BinaryPipeException( msg );
  }

  return bpipe_dpktf_data( field, core );

}

/**
   simple routine to get the data pointer for a named header data field 
*/
char* Photon::hdrf_data( BPipe* bpipe, const char *name, const int idx ) const 
  throw ( BinaryPipeException ) {

  char *field = (char *) bpipe_hdrf_data( bpipe, (char*)name, idx );

  if ( NULL == field ) {
    char msg[ 128 ];
    const char* format =
      "Photon::hdrf_data( Bpipe*, %s ) : missing `%s' header field\n";
    sprintf( msg, format, (char*)name, (char*)name );
    throw BinaryPipeException( msg );
  }

  return field;

}

