#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <assert.h>

#include <suplib/stats.h>

size_t read_data( char* file, double** rdata_pp );

int
main( int argc, char *argv[] )
{
  char* file1;
  char* file2;

  int nd1, nd2;
  int test;
  double *d1, *d2;
  double dstats[3], q;

  int rv, k, *m;
  
  if ( argc != 3 )
  {
    fprintf( stderr, "usage: test_smirnov file1 file2\n" );
    return EXIT_FAILURE;
  }

  file1 = argv[1];
  file2 = argv[2];

  nd1 = read_data( file1, &d1 );
  nd2 = read_data( file2, &d2 );

  rv = stcalc( 1, nd1, nd2, d1, d2, &k, &m, dstats );

  if ( rv )
  {
    fprintf( stderr, "stcalc returned %d\n", rv );
    return EXIT_FAILURE;
  }

  /* we want the two-sided test */
  test = 1;
  rv = gsmirn2( nd1, nd2, test, m, dstats[test-1], &q );

  /* underflow we don't care about */
  if ( rv && rv != 3)
  {
      fprintf( stderr, "gsmirn returned %d\n", rv );
      return EXIT_FAILURE;
  }

  printf( "%.14g\n", q );
  return EXIT_SUCCESS;
}

size_t
read_data( char* file, double** rdata_pp )
{
  char buffer[1024];
  size_t nrecords = 0;
  double *data, *tdata;

  FILE *fp = fopen( file, "r" );

  assert ( NULL != fp );

  /* count number of records */
  while( fgets( buffer, sizeof(buffer), fp ) )
    nrecords++;

  tdata = data = malloc( nrecords * sizeof(double) );
  assert( NULL != data );

  fseek( fp, 0L, SEEK_SET );

  while( fgets( buffer, sizeof(buffer), fp ) )
    *tdata++ = strtod( buffer, NULL );

  fclose( fp );

  *rdata_pp = data;
  return nrecords;
}
